.. :changelog:

History
-------

0.1.3 (2022-11-05)
++++++++++++++++++

* Support recent Django versions
* Use flit instead of setup.py

0.1.2 (2019-03-12)
++++++++++++++++++

* Allow upload to be added to existing model instance

0.1.1 (2019-02-28)
++++++++++++++++++

* Delete content_object of upload on revert, too
* Store upload in another apps model if app_name is provided in process path /process/app_name
* Added some tests

0.1.0 (2018-11-14)
++++++++++++++++++

* First release on PyPI.
